from __future__ import print_function
import json
import boto3
import logging
from botocore.exceptions import ClientError
import os

logger = logging.getLogger()
logger.setLevel(logging.INFO)


outbound_topic_arn = os.environ["outbound_topic_arn"]

key1 = os.environ["key1"]
key2 = os.environ["key2"]
value1 = os.environ["value1"]
value2 = os.environ["value2"]

def lambda_handler(event, context):
    print("=========================")

    region = event['region']
    detail = event['detail']
    eventname = detail['eventName']
    arn = detail['userIdentity']['arn']
    principal = detail['userIdentity']['principalId']
    userType = detail['userIdentity']['type']

    
    if userType == 'IAMUser':
        user = detail['userIdentity']['userName']
    else:
        user = principal.split(':')[1]

    logger.info('principalId: ' + str(principal))
    logger.info('region: ' + str(region))
    logger.info('eventName: ' + str(eventname))
    logger.info('detail: ' + str(detail))

    client = boto3.client('rds')
    resource_arn = detail['responseElements']['dBInstanceArn']

    if eventname == 'CreateDBInstance':
        tags = [{'Key': key1, 'Value': value1}, {'Key': key2, 'Value': value2}]
        client.add_tags_to_resource(ResourceName=resource_arn, Tags=tags)
        notify()
    else:
        logger.warning('Not supported action')
        
def notify():
    findsnsregion = outbound_topic_arn.split(":")
    snsregion = findsnsregion[3]
    sendclient = boto3.client('sns', region_name=snsregion)
    try:
        sendclient.publish(
            TopicArn=outbound_topic_arn,
            Message=("RDS is created and tagged"),
            Subject="RDS Information!"
        )
    except ClientError as err:
        log.error(err)
        return False
